@@ -122,7 +122,9 @@ sub _load_registry {
    my $self = shift;
 	eval { $HOME = (getpwuid($>))[7]; } unless $HOME;
 	if ($@) {
-		$self->warn("This Perl doesn't implement function getpwuid(), no \$HOME");
+		# Windows can have Win32::LoginName to get the Username, so check if it works before giving up
+		 ( defined &Win32::LoginName ) ? ( $HOME =  Win32::LoginName() )
+		:                                 $self->warn("This Perl doesn't implement function getpwuid(), no \$HOME");
 	}
 	my @ini_files = $self->_get_ini_files();
 
