@@ -74,7 +74,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-  https://redmine.open-bio.org/projects/bioperl/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Chris Fields
 
@@ -548,6 +548,9 @@ sub query_length {
            if available, for the hit
  Returns : a scalar string (empty string if not set)
  Args    : none
+ Note    : As of Sept. 2016 NCBI records will no longer have a
+           GI; this attributue will remain in place for older
+           records
 
 =cut
 
