@@ -128,7 +128,7 @@ only differences are in available initiator codons.
 
 NCBI Genetic Codes home page:
      (Last update of the Genetic Codes: April 30, 2013)
-     http://www.ncbi.nlm.nih.gov/Taxonomy/Utils/wprintgc.cgi?mode=c
+     https://www.ncbi.nlm.nih.gov/Taxonomy/Utils/wprintgc.cgi?mode=c
 
 ASN.1 version with ids 1 to 25 is at:
      ftp://ftp.ncbi.nih.gov/entrez/misc/data/gc.prt
@@ -726,7 +726,31 @@ sub is_start_codon{
 =cut
 
 sub is_ter_codon{
-    shift->_codon_is( shift, \@TABLES, $TERMINATOR );
+   my ($self, $value) = @_;
+   my $id = $self->{'id'};
+
+   # We need to ensure U is mapped to T (ie. UAG)
+   $value = uc $value;
+   $value =~ tr/U/T/;
+
+   if (length $value != 3  )  {
+       # Incomplete codons are not stop codons
+       return 0;
+   } else {
+       my $result = 0;
+
+       # For all the possible codons, if any are not a stop
+       # codon, fail immediately
+       for my $c ( $self->unambiguous_codons($value) ) {
+	   my $m = substr( $TABLES[$id], $CODONS->{$c}, 1 );
+	   if($m eq $TERMINATOR) {
+	       $result = 1;
+	   } else {
+	       return 0;
+	   }
+       }
+       return $result;
+   }
 }
 
 # desc: compares the passed value with a single entry in the given
