@@ -1,4 +1,4 @@
-#!/usr/bin/perl
+#!/usr/bin/env perl 
 
 # Demonstrates the use of a SearchIO Blast parser and a SearchWriterI object
 # for producing tab-delimited output of HSP data from a Blast report 
@@ -38,6 +38,7 @@
 # Author: Steve Chervitz <sac@bioperl.org>
 
 use strict;
+use lib '../../';
 
 use Bio::SearchIO;
 use Bio::SearchIO::Writer::HSPTableWriter;
